Fixed errors in the tests migrated to NNBD
diff --git a/Language/Classes/Constructors/name_t08.dart b/Language/Classes/Constructors/name_t08.dart
index 01f5fe3..a97d095 100644
--- a/Language/Classes/Constructors/name_t08.dart
+++ b/Language/Classes/Constructors/name_t08.dart
@@ -20,7 +20,7 @@
  */
 // SharedOptions=--enable-experiment=nonfunction-type-aliases
 class A {
-  static int get foo {}
+  static int get foo => 42;
 }
 typedef AAlias = A;
 
diff --git a/Language/Classes/method_definition_t06.dart b/Language/Classes/method_definition_t06.dart
index b2da254..fd2bbaf 100644
--- a/Language/Classes/method_definition_t06.dart
+++ b/Language/Classes/method_definition_t06.dart
@@ -25,6 +25,7 @@
  * @description Checks that there is a compile-time error if an operator
  * method definition in a concrete class does not include a body
  * @issue 27508
+ * @issue 42199
  * @compile-error
  * @author msyabro
  */
diff --git a/Language/Classes/Instance_Methods/Operators/return_type_t01.dart b/Language/Classes/Instance_Methods/Operators/return_type_t01.dart
index 088f201..8c7d43a 100644
--- a/Language/Classes/Instance_Methods/Operators/return_type_t01.dart
+++ b/Language/Classes/Instance_Methods/Operators/return_type_t01.dart
@@ -4,17 +4,18 @@
  * BSD-style license that can be found in the LICENSE file.
  */
 /**
  * @assertion It is a compile-time error if the return type of the user-declared
  * operator []= is explicitly declared and not void.
  * @description Checks that it is a compile-time error if the return type of
  * the user-declared operator []= is not void.
- * @compile-error
+ * @static-warning
  * @author msyabro
  * @author sgrekhov@unipro.ru
+ * @issue 42198
  */
 
 class C {
-  int operator[]=(index, value) => 42;
+  int operator []=(index, value) => 42; /// static type warning
   operator[](index) {}
 }
 
@@ -4,17 +4,18 @@
  */
 /**
- * @assertion It is a compile-time error if the return type of the user-declared
+ * @assertion It is a static warning if the return type of the user-declared
  * operator []= is explicitly declared and not void.
@@ -4,17 +4,18 @@
  * operator []= is explicitly declared and not void.
- * @description Checks that it is a compile-time error if the return type of
+ * @description Checks that it is a static warning if the return type of
  * the user-declared operator []= is not void.